<div class="peek-title-bar"
     [class.bg-danger]="!vortexIsOnline">
    <div  *ngIf="isEnabled"
               class="btn-group pull-left"
         role="group">
        <button class="title-bar-btn"
                [routerLink]="['/']">
            Home

        </button>
        <button
                class="title-bar-btn"
                *ngFor="let link of leftLinks"
                [routerLink]="[link.resourcePath]">
            {{linkTitle(link)}}

        </button>
    </div>
    <div class="title-bar-title">
        {{title}}
    </div>
    <div class="pull-right">
        <fa *ngIf="!vortexIsOnline" name="unlink"
            tooltip="Connection to server is offline"></fa>
        <div *ngIf="isEnabled"
                    class="btn-group"
             role="group">
            <button class="title-bar-btn"
                    *ngFor="let link of rightLinks"
                    [routerLink]="[link.resourcePath]">
                {{linkTitle(link)}}

            </button>
        </div>
    </div>
</div>
