<div class="peek-home-screen-background"></div>
<div class="peek-home-screen">
  <div class="container-fluid">
    <div class="row">
      <div class="title h3"
           *ngIf="!appDetails.length">
        No Plugins Installed

      </div>
      <div class="col-xs-6 col-sm-4 col-md-3 col-lg-2"
           *ngFor="let app of appDetails">
        <a class="home-screen-icon"
           [routerLink]="[app.resourcePath]">
          <img class="home-screen-image"
               [src]="[app.pluginIconPath]">
          <div class="home-screen-title">
            {{app.title}}

          </div>
        </a>
      </div>
    </div>
  </div>
</div>
